@@ -16,7 +16,6 @@ def make_keywords(dataset):
   kw_model = KeyBERT()
   df = pd.DataFrame(columns=['text', 'keywords'])
   df["text"] = dataset["text"] 
-  print(df)
   for i in tqdm(range(len(df))):
     keyword = kw_model.extract_keywords(df['text'][i])
     clean = clean_keywords(keyword)
@@ -24,7 +23,6 @@ def make_keywords(dataset):
   return df
 
 def make_dataset(dataset="common_gen", split="train"):
-  try:
     if dataset == "common_gen":
         dataset = load_dataset(dataset, split=split)
         df = pd.DataFrame()
@@ -34,7 +32,7 @@ def make_dataset(dataset="common_gen", split="train"):
         return df
     else:
         dataset = load_dataset(dataset, split=split)
+        print(dataset)
         df = make_keywords(df)
         return df
-  except Exception as e:
-    raise e
+  
\ No newline at end of file
